<script setup>
import AuthenticatedLayout from '@/Layouts/AuthenticatedLayout.vue';
import ProductFilter from '@/components/ProductFilter.vue'

import { ref, onMounted, computed } from 'vue';
import { Head, usePage, useForm } from '@inertiajs/vue3';

const page = usePage();
console.log(page);
const userDetails = computed(() => page.props.auth || []);
const orderDetails = computed(() => page.props.order || []);
const addresses = computed(() => page.props.addresses || []);
const cart = computed(() => page.props.productsDetails || []);
const products = computed(() => page.props.products || []);
const address = computed(() => page.props.address || []);
const isMobile = ref(window.innerWidth <= 768);
const flashMessage = ref('');
const cartShipping = ref('1');
const orderTotal = ref('');
const cartAddress = ref('primary');

const form = useForm({});

const handleResize = () => {
    isMobile.value = window.innerWidth <= 768;
}

const cartTotal = () => {
    let total = 0;
    cart.value.forEach(item => {
        total += item.price * item.cart_qty;
    });
    total = total.toFixed(2);
    orderTotal.value = total;
    return total;
};

onMounted(() => {
    window.addEventListener('resize', handleResize);
    handleResize();
    orderTotal.value = cartTotal();
});

const singleProduct = (item_number) => {
    window.location.href = `/product/${item_number}`;
};
</script>

<template>
    <Head title="Thank You" />

    <AuthenticatedLayout>
        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Thank you for your order!</h2>
        </template>

        <div class="py-12 container">
            <div class="row">
                <div v-if="flashMessage" class="col-12 max-w-7xl mx-auto sm:px-6 lg:px-8 font-bold text-red-600">
                    <div class="form-row mb-6">
                        <div class="col-md-6">
                            <h4>{{ flashMessage }}</h4>
                        </div>
                    </div>
                </div>

                <div class="col-12 col-sm-9 max-w-7xl mx-auto sm:px-6 lg:px-8 cart_details">
                    <h3>Order Products</h3>
                    <table style="width: 100%;">
                        <thead>
                            <tr>
                                <th>Qty</th>
                                <th>ItemNumber</th>
                                <th>Item Description</th>
                                <th>Price</th>
                                <th>Qty*Price</th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr v-for="product in cart" :key="product.id">
                                <td>{{ products.find(item => item.id == product.id).qty }}</td>
                                <td><a href="#" @click="singleProduct(product.item_number)">{{ product.item_number }}</a></td>
                                <td v-if="!isMobile" >{{ product.item_description }}</td>
                                <td>${{ product.price }}</td>
                                <td>${{ ((products.find(item => item.id == product.id).qty) * (product.price)).toFixed(2) }}</td>
                            </tr>
                        </tbody>
                    </table>
                </div>
                <div class="col-12 col-sm-3 max-w-7xl mx-auto sm:px-6 lg:px-8 order_summary">
                    <h3>Order Summary</h3>
                    <p><span class="text-left">Subtotal</span> <span class="text-right">${{ orderDetails.price }}</span></p>
                    <p><span class="text-left">Shipping</span> <span class="text-right">${{ orderDetails.shipping_price }}</span></p>
                    <p><span class="text-left">Tax</span> <span class="text-right">${{ orderDetails.tax }}</span></p>
                    <hr />
                    <p><b><span class="text-left">Total</span> <span class="text-right">${{ orderDetails.total_price }}</span></b></p>
                </div>
            </div>
            <div class="row shipping_details">
                <div class="col-12 col-sm-5 max-w-7xl mx-auto sm:px-6 lg:px-8 cart_details">
                    <h3>Shipping Infomration</h3>
                    <table style="width: 100%;">
                        <tr>
                            <td>Company</td>
                            <td>
                                {{ orderDetails.addressID == 'primary' ? userDetails.user.company : address.company}}
                            </td>
                        </tr>
                        <tr>
                            <td>Contact</td>
                            <td>
                                {{ orderDetails.addressID == 'primary' ? userDetails.user.name : address.contact}}
                            </td>
                        </tr>
                        <tr>
                            <td>Phone</td>
                            <td>
                                {{orderDetails.addressID == 'primary' ? userDetails.user.phone : address.phone}}
                            </td>
                        </tr>
                        <tr>
                            <td>Fax</td>
                            <td>
                                {{orderDetails.addressID == 'primary' ? userDetails.user.fax : address.fax}}
                            </td>
                        </tr>
                        <tr>
                            <td>Address 1</td>
                            <td>
                                {{orderDetails.addressID == 'primary' ? userDetails.user.address1 : address.address1}}
                            </td>
                        </tr>
                        <tr>
                            <td>Address 2</td>
                            <td>
                                {{orderDetails.addressID == 'primary' ? userDetails.user.address2 : address.address2}}
                            </td>
                        </tr>
                        <tr>
                            <td>City</td>
                            <td>
                                {{orderDetails.addressID == 'primary' ? userDetails.user.city : address.city}}
                            </td>
                        </tr>
                        <tr>
                            <td>Country</td>
                            <td>
                                {{orderDetails.addressID == 'primary' ? userDetails.user.country : address.country}}
                            </td>
                        </tr>
                        <tr>
                            <td>State</td>
                            <td>
                                {{orderDetails.addressID == 'primary' ? userDetails.user.state : address.state}}
                            </td>
                        </tr>
                        <tr>
                            <td>Zip</td>
                            <td>
                                {{orderDetails.addressID == 'primary' ? userDetails.user.postal : address.zip}}
                            </td>
                        </tr>
                    </table>
                </div>
                <div class="col-12 col-sm-4 max-w-7xl mx-auto sm:px-6 lg:px-8 cart_details">
                    <h3>Shipping Option</h3>
                    <table>
                        <tr>
                            <td>Shipping Method</td>
                            <td>20. Next Scheduled Delivery</td>
                        </tr>
                        <tr>
                            <td>Customer PO</td>
                            <td>{{ orderDetails.customer_po ? orderDetails.customer_po : '' }}</td>
                        </tr>
                    </table>
                </div>
                <div class="col-12 col-sm-3 max-w-7xl mx-auto sm:px-6 lg:px-8 order_summary">
                    <h4><b>Comment</b></h4>
                    {{ orderDetails.comment ? orderDetails.comment : '' }}
                </div>
            </div>
        </div>
    </AuthenticatedLayout>
</template>
<style scoped>
table tr td {
    max-width: 200px;
}
.cart_qty input {
    width: 70px;
    padding: 0 5px;
    height: 33px;
}
.cart_details h3, .order_summary h3, .cart_details table tr th {
    padding: 10px;
}
.cart_details table tr td {
    padding: 5px 10px;
}
.cart_details h3, .order_summary h3 {
    background-color: #ccc;
    font-weight: bold;
}
.order_summary p {
    padding: 5px 10px;
}
.order_summary p span[data-v-cb17554d] {
	width: 49%;
	display: inline-block;
}
.shipping_details {
    margin-top: 70px;
}
</style>
